include "textureResize.mse"

global resolutionArray = #(256, 512, 1024, 2048, 4096, 8192)

global retArr = CopyIcons()
if retArr.count != 0 then
(
	MessageBox "Installation of the 'Renderpeople Resizer Toolbar' was successful. Please restart 3ds Max.\n\nPlease note that a workspace change may require a 3ds Max restart to use the toolbar." title:"Information"
)
else
(
	global windowText = ""
	try 
	(
		windowText = uiaccessor.getWindowText(windows.getChildHWND #max "Renderpeople Resizer Toolbar")[1] -- toolbar ist docked
	) 
	catch 
	(
		try
		(
			windowText = uiaccessor.getWindowText(windows.getChildHWND 0 "Renderpeople Resizer Toolbar")[1] -- toolbar ist floated
		)
		catch
		(
			windowText = ""
		)
		
	) 
	if windowText == "" do
		InstallToolbar()
)
	
MacroScript TextureResizer category:"Renderpeople Resizer" tooltip:"Resize textures" icon:#("rp_resizer_toolbar", 1)
(
	try(destroyDialog dlg_main) catch()
	rollout dlg_main "Resize Textures" width:330 height:140
	(
		local my_path = getFilenamePath (getSourceFilename())
		local rPosX=0
		local posY=0
		local rWidth = 1000
		
		local newWidth = 0
		local suffixIndex = 0

		Button btnResize "Resize" pos:[rPosX+10, posY+95] width:150 height:30
		Button btnCancel "Cancel" pos:[rPosX+170, posY+95] width:150 height:30
		
		--Button btnTest "do stuff" pos:[rPosX+260, posY+120] width:80 height:30
		
		Slider sldResolution "Target Resolution" orient:#horizontal range:[1,6,0] type:#float ticks:5 pos:[rPosX+10, posY+25] width:250 height:40--orient:#horizontal --type:#integer
		dotNetControl dnc_lblResolutionOutput "Windows.Forms.Label" pos:[rPosX+260, posY+51] width:60 height:20
	
		on sldResolution changed val do 
		(
			local rounded = floor(val)
			sldResolution.value = rounded
			dnc_lblResolutionOutput.text = resolutionArray[rounded] as string + " px"
			newWidth = resolutionArray[rounded]
			suffixIndex = rounded
		)
		
		on dlg_main open do
		(
			bkgCol = (colorman.getcolor #background * 255) as color
			frgCol = (colorman.getcolor #text * 255) as color
			fontStyle = dotNetClass "System.Drawing.FontStyle"
			font = dotNetObject "System.Drawing.Font" "Arial" 10 fontStyle.bold
			
			dnc_lblResolutionOutput.backColor = (dotNetClass "System.Drawing.Color").fromArgb bkgCol.r bkgCol.g bkgCol.b
			dnc_lblResolutionOutput.foreColor = (dotNetClass "System.Drawing.Color").fromArgb frgCol.r frgCol.g frgCol.b
			dnc_lblResolutionOutput.font = font
			
			sldResolution.value = 5
			tempRes = resolutionArray[sldResolution.value]
			dnc_lblResolutionOutput.text = tempRes as string + " px"
			newWidth = tempRes
			suffixIndex = sldResolution.value
		)
		
		on btnCancel pressed do
		(
			destroydialog dlg_main
		)		
		
		on btnResize pressed do
		(
			ExecuteResize newWidth suffixIndex
			dlg_main.close()
		)
		
		on dlg_main close do
		(
			destroydialog dlg_main
		)
		
		/*
		on btnTest pressed do
		(
			debuglog("in btnTest pressed")
			local quality = (amax 0 (amin 100 85)) as Integer64
			local encoder = dotnetClass "System.Drawing.Imaging.Encoder"
			local qualityParam = dotnetObject "System.Drawing.Imaging.EncoderParameter" encoder.Quality (quality as Integer64)
			local jpegCodec = GetEncoderInfo "image/jpeg"
			local encoderParams = dotnetObject "System.Drawing.Imaging.EncoderParameters" 1
			encoderParams.Param = #(qualityParam)
			local tmpBitmap = dotNetClass "System.Drawing.Image"
			tmpBitmap.FromFile("C:/Users/User/Documents/Projects/3DS-Max_Texture/Texturen/Erde.png")
			
			debuglog("jpegCodec: " + jpegCodec as string)
			debuglog("encoderParams: " + encoderParams as string)
			debuglog("tmpBitmap: " + tmpBitmap as string)
			
			try(tmpBitmap.Save "test.jpg" jpegCodec encoderParams)
			catch(debuglog(getCurrentException()))
			
			try(destroyDialog dlg_main)
			catch()
		)
		*/
	)
	
	CreateDialog dlg_main style:#(#style_titlebar, #style_border, #style_sysmenu);
)

MacroScript TextureResizer1K category:"Renderpeople Resizer" tooltip:"Resize to 1k" icon:#("rp_resizer_toolbar", 2)
(
	ExecuteResize 1024 3
)

MacroScript TextureResizer2K category:"Renderpeople Resizer" tooltip:"Resize to 2k" icon:#("rp_resizer_toolbar", 3)
(
	ExecuteResize 2048 4
)

MacroScript TextureResizer4k category:"Renderpeople Resizer" tooltip:"Resize to 4k" icon:#("rp_resizer_toolbar", 4)
(
	ExecuteResize 4096 5
)

MacroScript SelectResizedTextures category:"Renderpeople Resizer" tooltip:"Select all resized textures" icon:#("rp_resizer_toolbar", 5)
(
	SelectResizedTextures()
)

MacroScript ResetTexturesAll category:"Renderpeople Resizer" tooltip:"Reset all textures" icon:#("rp_resizer_toolbar", 6)
(
	ResetResize 1
)

MacroScript ResetTexturesSelected category:"Renderpeople Resizer" tooltip:"Reset selected textures" icon:#("rp_resizer_toolbar", 7)
(
	ResetResize 2
)

MacroScript ShowInfoWindow category:"Renderpeople Resizer" tooltip:"Show plugin information" icon:#("rp_resizer_toolbar", 8)
(
	try(destroyDialog dlg_info) catch()
	rollout dlg_info "Renderpeople Resizer - Information" width:400 height:280
	(
		local rWidth = 100
		local rPosX = 762
		local posY = 120
		local myPath = getFilenamePath (getSourceFilename())
		
		local pluginVersion = "1.0"
		
		dotNetControl dnc_lblHeader "Windows.Forms.Label" pos:[0, 0] width:400 height:120
		dotNetControl dnc_lblLogo "Windows.Forms.Label" pos:[290, 220] width:100 height:50
		dotNetControl dnc_lblCopyright "Windows.Forms.Label" pos:[16, posY+10] width:400 height:20
		dotNetControl dnc_lblPluginversion "Windows.Forms.Label" pos:[16, posY+25] width:200 height:20
		dotNetControl dnc_lblHomepage "Windows.Forms.Label" pos:[16, posY+60] width:200 height:20
		dotNetControl dnc_lblUpdate "Windows.Forms.Label" pos:[16, posY+110] width:200 height:20
			
		hyperLink homepage "renderpeople.com" color:(color 252 146 44) hoverColor:(color 252 146 44) visitedColor:(color 252 146 44) address:"https://renderpeople.com/"	pos:[20,posY+78]
		hyperLink checkUpdate "Check" color:(color 252 146 44) hoverColor:(color 252 146 44) visitedColor:(color 252 146 44) address:"https://renderpeople.com/plugin" pos:[20,posY+128]
			
		on dlg_info open do
		(
			dnc_lblheader.Image = (dotNetClass "System.Drawing.image").fromFile (myPath + "res/rp_info_header.jpg")
			
			bkgCol = (colorman.getcolor #background * 255) as color
			frgCol = (colorman.getcolor #text * 255) as color
			fontStyle = dotNetClass "System.Drawing.FontStyle"
			
			font1 = dotNetObject "System.Drawing.Font" "Arial" 8 fontStyle.bold
			font2 = dotNetObject "System.Drawing.Font" "Arial" 10 fontStyle.bold
			
			dnc_lblCopyright.text = " 2016 Renderpeople - Cologne, Germany. All rights reserved."
			dnc_lblCopyright.backColor = (dotNetClass "System.Drawing.Color").fromArgb bkgCol.r bkgCol.g bkgCol.b
			dnc_lblCopyright.foreColor = (dotNetClass "System.Drawing.Color").fromArgb frgCol.r frgCol.g frgCol.b
			dnc_lblCopyright.font = font1
			
			dnc_lblPluginversion.text = "Plug-In Version: " + pluginVersion
			dnc_lblPluginversion.backColor = (dotNetClass "System.Drawing.Color").fromArgb bkgCol.r bkgCol.g bkgCol.b
			dnc_lblPluginversion.foreColor = (dotNetClass "System.Drawing.Color").fromArgb frgCol.r frgCol.g frgCol.b
			dnc_lblPluginversion.font = font1
			
			dnc_lblHomepage.text = "Visit us on our website"
			dnc_lblHomepage.backColor = (dotNetClass "System.Drawing.Color").fromArgb bkgCol.r bkgCol.g bkgCol.b
			dnc_lblHomepage.foreColor = (dotNetClass "System.Drawing.Color").fromArgb frgCol.r frgCol.g frgCol.b
			dnc_lblHomepage.font = font2
			
			dnc_lblUpdate.text = "Search for plug-in updates"
			dnc_lblUpdate.backColor = (dotNetClass "System.Drawing.Color").fromArgb bkgCol.r bkgCol.g bkgCol.b
			dnc_lblUpdate.foreColor = (dotNetClass "System.Drawing.Color").fromArgb frgCol.r frgCol.g frgCol.b
			dnc_lblUpdate.font = font2
			
			dnc_lblLogo.image = (dotNetClass "System.Drawing.Image").fromFile (myPath + "res/rp_logo.png")
			dnc_lblLogo.backColor = (dotNetClass "System.Drawing.Color").fromArgb bkgCol.r bkgCol.g bkgCol.b
		)
		on dlg_info close do
		(
			destroydialog dlg_info
		)
	)
	CreateDialog dlg_info style:#(#style_titlebar, #style_sysmenu)
)